@@ -1,4 +1,4 @@
-/* $Id: glibmm.h 667 2008-06-13 15:51:43Z murrayc $ */
+/* $Id: glibmm.h 700 2008-07-29 10:27:08Z murrayc $ */
 
 /* glibmm - a C++ wrapper for the GLib toolkit
  *
@@ -46,6 +46,7 @@
 #include <glibmm/markup.h>
 #include <glibmm/miscutils.h>
 #include <glibmm/module.h>
+#include <glibmm/nodetree.h>
 #include <glibmm/objectbase.h>
 #include <glibmm/object.h>
 #include <glibmm/optioncontext.h>
@@ -67,7 +68,6 @@
 #include <glibmm/threadpool.h>
 #include <glibmm/timer.h>
 #include <glibmm/timeval.h>
-#include <glibmm/tree.h>
 #include <glibmm/uriutils.h>
 #include <glibmm/ustring.h>
 #include <glibmm/value.h>
