@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_CONTAINERS_H
 #define _GLIBMM_CONTAINERS_H
 
-/* $Id: containers.h,v 1.7 2005/11/23 07:22:43 murrayc Exp $ */
+/* $Id: containers.h 749 2008-12-10 14:23:33Z jjongsma $ */
 
 /* containers.h
  *
@@ -23,8 +23,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <glib/glist.h>
-#include <glib/gslist.h>
+#include <glib.h>
 #include <glibmm/sarray.h> /* for backward compatibility */
 
 #include <iterator>
