@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_MAIN_H
 #define _GLIBMM_MAIN_H
 
-/* $Id: main.h 420 2007-06-22 15:29:58Z murrayc $ */
+/* $Id: main.h 749 2008-12-10 14:23:33Z jjongsma $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -21,8 +21,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <glib/giochannel.h>
-#include <glib/gmain.h>
+#include <glib.h>
 
 #include <vector>
 #include <sigc++/sigc++.h>
@@ -30,6 +29,7 @@
 #include <glibmmconfig.h>
 #include <glibmm/refptr.h>
 #include <glibmm/timeval.h>
+#include <glibmm/priorities.h>
 
 GLIBMM_USING_STD(vector)
 
@@ -47,41 +47,6 @@ class IOChannel;
  * @{
  */
 
-enum
-{
-  /*! Use this for high priority event sources.  It is not used within
-   * GLib or GTK+.<br><br>
-   */
-  PRIORITY_HIGH = -100,
-
-  /*! Use this for default priority event sources.  In glibmm this
-   * priority is used by default when installing timeout handlers with
-   * SignalTimeout::connect().  In GDK this priority is used for events
-   * from the X server.<br><br>
-   */
-  PRIORITY_DEFAULT = 0,
-
-  /*! Use this for high priority idle functions.  GTK+ uses
-   * <tt>PRIORITY_HIGH_IDLE&nbsp;+&nbsp;10</tt> for resizing operations, and
-   * <tt>PRIORITY_HIGH_IDLE&nbsp;+&nbsp;20</tt> for redrawing operations.
-   * (This is done to ensure that any pending resizes are processed before
-   * any pending redraws, so that widgets are not redrawn twice unnecessarily.)
-   * <br><br>
-   */
-  PRIORITY_HIGH_IDLE = 100,
-
-  /*! Use this for default priority idle functions.  In glibmm this priority is
-   * used by default when installing idle handlers with SignalIdle::connect().
-   * <br><br>
-   */
-  PRIORITY_DEFAULT_IDLE = 200,
-
-  /*! Use this for very low priority background tasks.  It is not used within
-   * GLib or GTK+.
-   */
-  PRIORITY_LOW = 300
-};
-
 
 /** A bitwise combination representing an I/O condition to watch for on an
  * event source.
