@@ -1,7 +1,7 @@
 // -*- c++ -*-
 #ifndef _GLIBMM_UTILITY_H
 #define _GLIBMM_UTILITY_H
-/* $Id: utility.h 387 2007-03-23 17:31:51Z murrayc $ */
+/* $Id: utility.h 749 2008-12-10 14:23:33Z jjongsma $ */
 
 /* Copyright 2002 The gtkmm Development Team
  *
@@ -20,8 +20,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <glib/gmacros.h>
-#include <glib/gmem.h>
+#include <glib.h>
 #include <glibmm/ustring.h>
 
 
