@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: wrap.cc 658 2008-04-24 15:53:38Z jjongsma $ */
+/* $Id: wrap.cc 749 2008-12-10 14:23:33Z jjongsma $ */
 
 /* wrap.cc
  *
@@ -21,8 +21,7 @@
  */
 
 #include <glib-object.h>
-#include <glib/gtypes.h>
-#include <glib/gmacros.h>
+#include <glib.h>
 
 #include <vector>
 #include <glibmm/object.h>
